@@ -1,5 +1,5 @@
 package Code::TidyAll::Git::Precommit;
-$Code::TidyAll::Git::Precommit::VERSION = '0.20';
+$Code::TidyAll::Git::Precommit::VERSION = '0.21';
 use Capture::Tiny qw(capture_stdout capture_stderr);
 use Code::TidyAll;
 use Code::TidyAll::Util qw(dirname mkpath realpath tempdir_simple write_file);
@@ -69,18 +69,15 @@ sub check {
 
 1;
 
+# ABSTRACT: Git pre-commit hook that requires files to be tidyall'd
+
 __END__
 
 =pod
 
-=head1 NAME
-
-Code::TidyAll::Git::Precommit - Git pre-commit hook that requires files to be
-tidyall'd
-
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -97,10 +94,10 @@ version 0.20
 
 This module implements a L<Git pre-commit
 hook|http://git-scm.com/book/en/Customizing-Git-Git-Hooks> that checks if all
-files are tidied and valid according to L<tidyall|tidyall>, and rejects the
+files are tidied and valid according to L<tidyall>, and rejects the
 commit if not. Files/commits are never modified by this hook.
 
-See also L<Code::TidyAll::Git::Prereceive|Code::TidyAll::Git::Prereceive>,
+See also L<Code::TidyAll::Git::Prereceive>,
 which validates pushes to a shared repo.
 
 =head1 METHODS
@@ -110,10 +107,10 @@ which validates pushes to a shared repo.
 =item check (key/value params...)
 
 Class method. Check that all files being added or modified in this commit are
-tidied and valid according to L<tidyall|tidyall>. If not, then the entire
+tidied and valid according to L<tidyall>. If not, then the entire
 commit is rejected and the reason(s) are output to the client. e.g.
 
-    % git commit -m "fixups" CHI.pm CHI/Driver.pm 
+    % git commit -m "fixups" CHI.pm CHI/Driver.pm
     2 files did not pass tidyall check
     lib/CHI.pm: *** 'PerlTidy': needs tidying
     lib/CHI/Driver.pm: *** 'PerlCritic': Code before strictures are enabled
@@ -161,11 +158,11 @@ process even files that are not going to be committed.
 
 =item tidyall_class
 
-Subclass to use instead of L<Code::TidyAll|Code::TidyAll>
+Subclass to use instead of L<Code::TidyAll>
 
 =item tidyall_options
 
-Hashref of options to pass to the L<Code::TidyAll|Code::TidyAll> constructor
+Hashref of options to pass to the L<Code::TidyAll> constructor
 
 =back
 
@@ -217,20 +214,30 @@ of the repo
 More information on pre-commit hooks and the impossibility of enforcing them
 L<here|http://stackoverflow.com/questions/3703159/git-remote-shared-pre-commit-hook>.
 
-See also L<Code::TidyAll::Git::Prereceive|Code::TidyAll::Git::Prereceive>,
+See also L<Code::TidyAll::Git::Prereceive>,
 which enforces tidyall on pushes to a remote shared repository.
 
 =head1 SEE ALSO
 
-L<Code::TidyAll|Code::TidyAll>
+L<Code::TidyAll>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Jonathan Swartz <swartz@pobox.com>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2014 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
