@@ -1,5 +1,5 @@
 package Code::TidyAll::Plugin::JSON;
-$Code::TidyAll::Plugin::JSON::VERSION = '0.20';
+$Code::TidyAll::Plugin::JSON::VERSION = '0.21';
 use strict;
 use warnings;
 
@@ -14,7 +14,7 @@ sub transform_source {
     my $self   = shift;
     my $source = shift;
 
-    my $json = JSON->new->relaxed->pretty->canonical;
+    my $json = JSON->new->utf8->relaxed->pretty->canonical;
 
     $json = $json->ascii if $self->ascii;
 
@@ -23,17 +23,15 @@ sub transform_source {
 
 1;
 
+# ABSTRACT: Use the JSON module to tidy JSON documents with tidyall
+
 __END__
 
 =pod
 
-=head1 NAME
-
-Code::TidyAll::Plugin::JSON - use the JSON module with tidyall
-
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -60,15 +58,25 @@ Escape non-ASCII characters. The output file will be valid ASCII.
 
 =head1 SEE ALSO
 
-L<Code::TidyAll|Code::TidyAll>
+L<Code::TidyAll>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Jonathan Swartz <swartz@pobox.com>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2014 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
