@@ -1,5 +1,5 @@
 package Code::TidyAll::Plugin::PerlCritic;
-$Code::TidyAll::Plugin::PerlCritic::VERSION = '0.20';
+$Code::TidyAll::Plugin::PerlCritic::VERSION = '0.21';
 use Capture::Tiny qw(capture_merged);
 use Moo;
 extends 'Code::TidyAll::Plugin';
@@ -16,17 +16,15 @@ sub validate_file {
 
 1;
 
+# ABSTRACT: Use perlcritic with tidyall
+
 __END__
 
 =pod
 
-=head1 NAME
-
-Code::TidyAll::Plugin::PerlCritic - use perlcritic with tidyall
-
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -46,7 +44,7 @@ version 0.20
 
 =head1 DESCRIPTION
 
-Runs L<perlcritic|perlcritic>, a Perl validator, and dies if any problems were
+Runs L<perlcritic>, a Perl validator, and dies if any problems were
 found.
 
 =head1 INSTALLATION
@@ -67,15 +65,25 @@ Arguments to pass to perlcritic
 
 =head1 SEE ALSO
 
-L<Code::TidyAll|Code::TidyAll>
+L<Code::TidyAll>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Jonathan Swartz <swartz@pobox.com>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2014 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
