@@ -1,5 +1,5 @@
 package Code::TidyAll::Result;
-$Code::TidyAll::Result::VERSION = '0.20';
+$Code::TidyAll::Result::VERSION = '0.21';
 use Moo;
 
 has 'error'        => ( is => 'ro' );
@@ -11,17 +11,15 @@ sub ok { return $_[0]->state ne 'error' }
 
 1;
 
+# ABSTRACT: Result returned from processing a file/source
+
 __END__
 
 =pod
 
-=head1 NAME
-
-Code::TidyAll::Result - Result returned from processing a file/source
-
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -80,15 +78,25 @@ Returns true iff state is not 'error'
 
 =head1 SEE ALSO
 
-L<Code::TidyAll|Code::TidyAll>
+L<Code::TidyAll>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Jonathan Swartz <swartz@pobox.com>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2014 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
