@@ -1,5 +1,5 @@
 package Code::TidyAll::SVN::Precommit;
-$Code::TidyAll::SVN::Precommit::VERSION = '0.20';
+$Code::TidyAll::SVN::Precommit::VERSION = '0.21';
 use Capture::Tiny qw(capture_stdout capture_stderr);
 use Code::TidyAll;
 use Code::TidyAll::Util qw(basename dirname mkpath realpath tempdir_simple write_file);
@@ -160,18 +160,15 @@ sub cat_file {
 
 1;
 
+# ABSTRACT: Subversion pre-commit hook that requires files to be tidyall'd
+
 __END__
 
 =pod
 
-=head1 NAME
-
-Code::TidyAll::SVN::Precommit - Subversion pre-commit hook that requires files
-to be tidyall'd
-
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -182,14 +179,14 @@ version 0.20
     use Log::Any::Adapter (File => "/path/to/hooks/logs/tidyall.log");
     use strict;
     use warnings;
-    
+
     Code::TidyAll::SVN::Precommit->check();
 
 =head1 DESCRIPTION
 
 This module implements a L<Subversion pre-commit
 hook|http://svnbook.red-bean.com/en/1.7/svn.ref.reposhooks.pre-commit.html>
-that checks if all files are tidied and valid according to L<tidyall|tidyall>,
+that checks if all files are tidied and valid according to L<tidyall>,
 and rejects the commit if not.
 
 =head1 METHODS
@@ -199,10 +196,10 @@ and rejects the commit if not.
 =item check (key/value params...)
 
 Class method. Check that all files being added or modified in this commit are
-tidied and valid according to L<tidyall|tidyall>. If not, then the entire
+tidied and valid according to L<tidyall>. If not, then the entire
 commit is rejected and the reason(s) are output to the client. e.g.
 
-    % svn commit -m "fixups" CHI.pm CHI/Driver.pm 
+    % svn commit -m "fixups" CHI.pm CHI/Driver.pm
     Sending        CHI/Driver.pm
     Sending        CHI.pm
     Transmitting file data ..svn: Commit failed (details follow):
@@ -216,11 +213,11 @@ commit is rejected and the reason(s) are output to the client. e.g.
 In an emergency the hook can be bypassed by prefixing the comment with "NO
 TIDYALL", e.g.
 
-    % svn commit -m "NO TIDYALL - this is an emergency!" CHI.pm CHI/Driver.pm 
+    % svn commit -m "NO TIDYALL - this is an emergency!" CHI.pm CHI/Driver.pm
     Sending        CHI/Driver.pm
     Sending        CHI.pm
-    Transmitting file data .                                                              
-    Committed revision 7562.  
+    Transmitting file data .
+    Committed revision 7562.
 
 The configuration file (C<tidyall.ini> or C<.tidyallrc>) must be checked into
 svn. For each file, the hook will look upwards from the file's repo location
@@ -270,11 +267,11 @@ Repository path being committed; defaults to C<< $ARGV[0] >>
 
 =item tidyall_class
 
-Subclass to use instead of L<Code::TidyAll|Code::TidyAll>
+Subclass to use instead of L<Code::TidyAll>
 
 =item tidyall_options
 
-Hashref of options to pass to the L<Code::TidyAll|Code::TidyAll> constructor
+Hashref of options to pass to the L<Code::TidyAll> constructor
 
 =item txn
 
@@ -286,7 +283,7 @@ Commit transaction; defaults to C<< $ARGV[1] >>
 
 =head1 LOGGING
 
-This module uses L<Log::Any|Log::Any> to log its activity, including all files
+This module uses L<Log::Any> to log its activity, including all files
 that were checked, an inability to find the configuration file, and any runtime
 errors that occur. You can create a simple date-stamped log file with
 
@@ -306,15 +303,25 @@ for some of the ideas here such as emergency_comment_prefix.
 
 =head1 SEE ALSO
 
-L<Code::TidyAll|Code::TidyAll>
+L<Code::TidyAll>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Jonathan Swartz <swartz@pobox.com>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2014 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
