@@ -1,5 +1,5 @@
 package Test::Code::TidyAll;
-$Test::Code::TidyAll::VERSION = '0.20';
+$Test::Code::TidyAll::VERSION = '0.21';
 use IPC::System::Simple qw(run);
 use Code::TidyAll;
 use Test::Builder;
@@ -20,7 +20,13 @@ sub tidyall_ok {
         $conf_file = Code::TidyAll->find_conf_file( \@conf_names, "." );
     }
     my $ct =
-      Code::TidyAll->new_from_conf_file( $conf_file, check_only => 1, mode => 'test', %options );
+    Code::TidyAll->new_from_conf_file(
+        $conf_file,
+        quiet      => 1,
+        check_only => 1,
+        mode       => 'test',
+        %options,
+    );
     my @files = $ct->find_matched_files;
     $test->plan( tests => scalar(@files) );
     foreach my $file (@files) {
@@ -30,26 +36,23 @@ sub tidyall_ok {
             $test->ok( 1, $desc );
         }
         else {
-            $test->diag( $result->error );
             $test->ok( 0, $desc );
+            $test->diag( $result->error );
         }
     }
 }
 
 1;
 
+# ABSTRACT: Check that all your files are tidy and valid according to tidyall
+
 __END__
 
 =pod
 
-=head1 NAME
-
-Test::Code::TidyAll - check that all your files are tidy and valid according to
-tidyall
-
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -67,12 +70,12 @@ would change the contents of the file. Does not actually modify any files.
 
 By default, looks for config file C<tidyall.ini> or C<.tidyallrc> in the
 current directory and parent directories, which is generally the right place if
-you are running L<prove|prove>.
+you are running L<prove>.
 
 Passes mode = "test" by default; see L<modes|tidyall/MODES>.
 
 C<tidyall_ok> is exported by default. Any options will be passed along to the
-L<Code::TidyAll|Code::TidyAll> constructor. For example, if you don't want to
+L<Code::TidyAll> constructor. For example, if you don't want to
 use the tidyall cache and instead check all files every time:
 
     tidyall_ok(no_cache => 1);
@@ -83,15 +86,25 @@ or if you need to specify the config file:
 
 =head1 SEE ALSO
 
-L<tidyall|tidyall>
+L<tidyall>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Jonathan Swartz <swartz@pobox.com>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2014 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
